pub enum PowerupOnMode {
On,
Toggle,
Previous,
}Variants
On
Use the value specified in the PowerupOnState on property.
Toggle
Alternate between on and off on each subsequent power toggle.
Previous
Return to the state it was in before powering off.