pub struct StreamProxy {
pub mode: StreamProxyMode,
pub node: ResourceIdentifier,
}Fields
mode: StreamProxyModeProxymode used for this group.
node: ResourceIdentifierReference to the device acting as proxy.
The proxy node relays the entertainment traffic and should be located in or close to all entertainment lamps in this group.
The node set by the application (StreamProxyMode::Manual) resp selected by the bridge (StreamProxyMode::Auto).
Writing sets mode to StreamProxyMode::Manual. Is not allowed to be combined with StreamProxyMode::Auto.
Can be type ResourceType::Bridge or ResourceType::ZigbeeConnectivity.